@@ -140,7 +140,7 @@ def job(job_name: str) -> Callable:
             from kih_api.communication import telegram
             try:
                 telegram.send_message(
-                    telegram.constants.telegram_channel_username,
+                    telegram.constants.telegram_debug_channel_username,
                     f"Running job: <i>{job_name}</i>", True)
                 logger.debug(f"Running job: {job_name}")
                 func(*args, **kwargs)
@@ -148,7 +148,7 @@ def job(job_name: str) -> Callable:
                 message = f"<b><u>ERROR</u></b>\n\nJob Name: <i>{job_name}</i>\nError Type: <i>{type(e).__name__}</i>"
                 if str(e) != "":
                     message = message + f"\nError Message: <i>{str(e).replace('<', '').replace('>', '')}</i>"
-                telegram.send_message(telegram.constants.telegram_channel_username, message,
+                telegram.send_message(telegram.constants.telegram_debug_channel_username, message,
                                                     True)
                 raise Exception(e)
             finally:
