@@ -167,11 +167,6 @@ class ExchangeRate(ResponseObject):
         return common.get_model_from_response(response, cls)[0]  # type: ignore
 
 
-@dataclass
-class Details:
-    reference: Optional[str] = None
-
-
 @dataclass
 class Transfer(ResponseObject):
     transferRequest: None = None
@@ -186,7 +181,7 @@ class Transfer(ResponseObject):
     rate: Optional[float] = None
     created: Optional[str] = None
     business: Optional[int] = None
-    details: Optional[Details] = None
+    details: Optional["Details"] = None
     hasActiveIssues: Optional[bool] = None
     sourceCurrency: Optional[str] = None
     sourceValue: Optional[float] = None
@@ -480,15 +475,6 @@ class IntraAccountTransfer(ResponseObject):
         return common.get_model_from_response(response, cls)  # type: ignore
 
 
-@dataclass
-class Address:
-    stateCode: None = None
-    addressFirstLine: Optional[str] = None
-    city: Optional[str] = None
-    postCode: Optional[str] = None
-    countryName: Optional[str] = None
-
-
 @dataclass
 class AccountHolder:
     type: Optional[str] = None
@@ -537,12 +523,6 @@ class Request:
     intervalEnd: Optional[str] = None
 
 
-@dataclass
-class Recipient:
-    name: Optional[str] = None
-    bankAccount: Optional[str] = None
-
-
 @dataclass
 class Details:
     type: Optional[str] = None
